@@ -3,6 +3,7 @@ import signal
 
 import numpy as np
 import pandas as pd
+from PyNumeca.constants import constants
 
 from PyNumeca.fine import fine
 from PyNumeca.igg import igg
@@ -18,7 +19,8 @@ class Simulation(object):
                  working_path: str = None,
                  geomturbo_path: str = None,
                  iec_path: str = None,
-                 trb_path: str = None):
+                 trb_path: str = None,
+                 version: str = None):
 
         if working_path is not None:
             self.working_path = working_path
@@ -28,6 +30,10 @@ class Simulation(object):
             self.iec_path = iec_path
         if trb_path is not None:
             self.trb_path = trb_path
+        if version is None:
+            self.version = constants.version
+        else:
+            self.version = version
 
         self.name = name
         self.runfile = None
@@ -39,19 +45,21 @@ class Simulation(object):
             self.trb_path,
             self.geomturbo_path,
             # new_trb,
-            os.path.join(self.working_path, self.name, self.name + '.igg'))
+            os.path.join(self.working_path, self.name, self.name + '.igg'),
+            igg_version=self.version)
 
     def generate_run(self, index: int = 0):
         fine.fine_run_from_mesh(self.iec_path,
                                 os.path.join(self.working_path, self.name, self.name + '.igg'),
                                 os.path.join(self.working_path, self.name, self.name + '.iec'),
-                                index=index)
+                                index=index,
+                                fine_version=self.version)
 
     @staticmethod
-    def setup_parallel_computation(run_file_path: str, cores: int = 20):
-        fine.setup_parallel_computation(run_file_path, cores=cores)
+    def setup_parallel_computation(run_file_path: str, cores: int = 20, version: str = constants.version):
+        fine.setup_parallel_computation(run_file_path, cores=cores, fine_version=version)
 
-    def run_pipeline(self, cores: int = 20, index: int = 0):
+    def run_pipeline(self, cores: int = 20, index: int = 0, use_intel_mpi: bool = False):
         self.make_mesh()
         self.generate_run(index)
         all_subdirs = [os.path.join(self.working_path, self.name, d) for d in
@@ -68,13 +76,13 @@ class Simulation(object):
         self.runfile = str(max(all_runfiles, key=os.path.getmtime))
         self.resfile = os.path.splitext(self.runfile)[0] + '.res'
         print('Latest run file:', self.runfile)
-        self.setup_parallel_computation(self.runfile, cores)
+        self.setup_parallel_computation(self.runfile, cores, version=self.version)
 
         run_file_dir = os.path.split(self.runfile)[0]
         run_file_base_name = os.path.splitext(os.path.split(self.runfile)[1])[0]
         batch_file = os.path.join(run_file_dir, run_file_base_name + '.batch')
 
-        self.run_parallel_computation(batch_file)
+        self.run_parallel_computation(batch_file, use_intel_mpi)
 
     def read_resfile(self):
         with open(self.resfile, 'r') as f:
@@ -94,8 +102,8 @@ class Simulation(object):
             mf_path = os.path.splitext(self.runfile)[0] + '.mf'
             return mf.read_mf(mf_file=mf_path)
 
-    def run_parallel_computation(self, batch_path: str):
-        self.runpid = fine.run_parallel_computation(batch_path)
+    def run_parallel_computation(self, batch_path: str, use_intel_mpi: bool = False):
+        self.runpid = fine.run_parallel_computation(batch_path, use_intel_mpi=use_intel_mpi)
 
     def kill_parallel_computation(self):
         if self.runpid is not None:
